@@ -16,10 +16,18 @@
 
 var fs = require('fs');
 var path = require('path');
+var child_process = require("child_process");
 
 module.exports = function (config) {
   // This tox venv is setup in the post-install npm step
-  var toxPath = '../.tox/py27/lib/python2.7/site-packages/';
+  var pythonVersion = "python3.";
+  var stdout = child_process.execFileSync("python3", ["--version"]);
+  pythonVersion += stdout.toString().split(".")[1];
+  var toxPath = '../.tox/karma/lib/' + pythonVersion + '/site-packages/';
+  console.log("Karma will check on directory: ", toxPath);
+
+
+  process.env.PHANTOMJS_BIN = 'node_modules/phantomjs-prebuilt/bin/phantomjs';
 
   config.set({
     preprocessors: {
@@ -69,7 +77,7 @@ module.exports = function (config) {
 
 
       // TODO: These should be mocked.
-      toxPath + '/horizon/static/horizon/js/horizon.js',
+      toxPath + 'horizon/static/horizon/js/horizon.js',
 
       /**
        * Include framework source code from horizon that we need.
@@ -120,7 +128,8 @@ module.exports = function (config) {
 
     frameworks: ['jasmine'],
 
-    browsers: ['Chrome'],
+    // browsers: ['Chrome'],
+    browsers: ['PhantomJS'],
 
     browserNoActivityTimeout: 60000,
 
@@ -128,6 +137,7 @@ module.exports = function (config) {
 
     plugins: [
       'karma-chrome-launcher',
+      'karma-phantomjs-launcher',
       'karma-jasmine',
       'karma-ng-html2js-preprocessor',
       'karma-coverage',
