@@ -30,20 +30,29 @@
     var ctrl = this;
     ctrl.cluster_template = {};
     ctrl.image_uuid = "";
+    ctrl.objLen = objLen;
 
     $scope.context.loadPromise.then(onGetClusterTemplate);
 
     function onGetClusterTemplate(template) {
       ctrl.cluster_template = template.data;
-      glance.getImages().success(onGetImages);
+      glance.getImages().then(onGetImages);
     }
 
     function onGetImages(images) {
-      angular.forEach(images.items, function(image) {
+      angular.forEach(images.data.items, function(image) {
         if (image.name === ctrl.cluster_template.image_id) {
           ctrl.image_uuid = image.id;
         }
       });
     }
+
+    function objLen(obj) {
+      var length = 0;
+      if (typeof obj === 'object') {
+        length = Object.keys(obj).length;
+      }
+      return length;
+    }
   }
 })();
