@@ -30,16 +30,25 @@
     var ctrl = this;
     ctrl.cluster = {};
     ctrl.cluster_template = {};
+    ctrl.objLen = objLen;
 
     $scope.context.loadPromise.then(onGetCluster);
 
     function onGetCluster(cluster) {
       ctrl.cluster = cluster.data;
-      magnum.getClusterTemplate(ctrl.cluster.cluster_template_id).success(onGetClusterTemplate);
+      magnum.getClusterTemplate(ctrl.cluster.cluster_template_id).then(onGetClusterTemplate);
     }
 
     function onGetClusterTemplate(clusterTemplate) {
-      ctrl.cluster_template = clusterTemplate;
+      ctrl.cluster_template = clusterTemplate.data;
+    }
+
+    function objLen(obj) {
+      var length = 0;
+      if (typeof obj === 'object') {
+        length = Object.keys(obj).length;
+      }
+      return length;
     }
   }
 })();
